@@ -14,10 +14,9 @@ click_log.basic_config(logger)
 
 
 @with_plugins(get_group_named("carlae.cli").values())
-@click.group(context_settings={
-    "auto_envvar_prefix": "CARLAE",
-    "max_content_width": 100,
-})
+@click.group(
+    context_settings={"auto_envvar_prefix": "CARLAE", "max_content_width": 100,}
+)
 @click_log.simple_verbosity_option(logger, "--log-level", show_default=True)
 def cli():
     """carlae command-line-interface"""
